@@ -43,7 +43,7 @@ static int epfd;
 static struct epoll_event evt;
 
 
-static int
+static enum MHD_Result
 ahc_echo (void *cls,
           struct MHD_Connection *connection,
           const char *url,
@@ -52,7 +52,7 @@ ahc_echo (void *cls,
           const char *upload_data, size_t *upload_data_size, void **ptr)
 {
   struct MHD_Response *response;
-  int ret;
+  enum MHD_Result ret;
   struct Request*req;
   struct itimerspec ts;
 
