@@ -511,8 +511,7 @@ wr_send (struct wr_socket *s,
     ssize_t ret;
 
     ret = MHD_send_ (s->fd, buf, len);
-    (void) MHD_socket_cork_ (s->fd,
-                             false);
+
     return ret;
   }
 #ifdef HTTPS_SUPPORT
@@ -882,10 +881,6 @@ run_usock (void *cls)
 {
   struct MHD_UpgradeResponseHandle *urh = cls;
 
-  if (MHD_YES !=
-      MHD_upgrade_action (urh,
-                          MHD_UPGRADE_ACTION_CORK_OFF))
-    abort ();
   send_all (usock,
             LARGE_STRING);
   recv_all (usock,
@@ -1085,8 +1080,6 @@ run_mhd_select_loop (struct MHD_Daemon *daemon)
   MHD_UNSIGNED_LONG_LONG to;
   struct timeval tv;
 
-  if (! MHD_itc_init_ (kicker))
-    abort ();
   while (! done)
   {
     FD_ZERO (&rs);
@@ -1122,8 +1115,6 @@ run_mhd_select_loop (struct MHD_Daemon *daemon)
                          &ws,
                          &es);
   }
-  (void) MHD_itc_destroy_ (kicker);
-  MHD_itc_set_invalid_ (kicker);
 }
 
 
@@ -1164,8 +1155,6 @@ run_mhd_epoll_loop (struct MHD_Daemon *daemon)
   di = MHD_get_daemon_info (daemon,
                             MHD_DAEMON_INFO_EPOLL_FD);
   ep = di->listen_fd;
-  if (! MHD_itc_init_ (kicker))
-    abort ();
   while (! done)
   {
     FD_ZERO (&rs);
@@ -1191,8 +1180,6 @@ run_mhd_epoll_loop (struct MHD_Daemon *daemon)
       MHD_itc_clear_ (kicker);
     MHD_run (daemon);
   }
-  (void) MHD_itc_destroy_ (kicker);
-  MHD_itc_set_invalid_ (kicker);
 }
 
 
@@ -1329,6 +1316,12 @@ test_upgrade (int flags,
 #endif /* !HTTPS_SUPPORT || !HAVE_FORK || !HAVE_WAITPID */
   }
 
+  if (0 == (flags & MHD_USE_INTERNAL_POLLING_THREAD) )
+  {
+    if (! MHD_itc_init_ (kicker))
+      abort ();
+  }
+
   if (0 != pthread_create (&pt_client,
                            NULL,
                            &run_usock_client,
@@ -1336,13 +1329,13 @@ test_upgrade (int flags,
     abort ();
   if (0 == (flags & MHD_USE_INTERNAL_POLLING_THREAD) )
   {
-    enum MHD_FLAG flags;
+    enum MHD_FLAG used_flags;
 
     /* make address sanitizer happy */
-    memcpy (&flags,
+    memcpy (&used_flags,
             real_flags /* ->flags */,
-            sizeof (flags));
-    run_mhd_loop (d, flags);
+            sizeof (used_flags));
+    run_mhd_loop (d, used_flags);
   }
   pthread_join (pt_client,
                 NULL);
@@ -1352,6 +1345,11 @@ test_upgrade (int flags,
   if (test_tls && (TLS_LIB_GNUTLS != use_tls_tool))
     waitpid (pid, NULL, 0);
 #endif /* HTTPS_SUPPORT && HAVE_FORK && HAVE_WAITPID */
+  if (0 == (flags & MHD_USE_INTERNAL_POLLING_THREAD) )
+  {
+    (void) MHD_itc_destroy_ (kicker);
+    MHD_itc_set_invalid_ (kicker);
+  }
   MHD_stop_daemon (d);
   return 0;
 }
