@@ -77,9 +77,10 @@
 
 /* Cleanup test: max number of concurrent daemons depending on maximum number
  * of open FDs. */
-#define CLEANUP_MAX_DAEMONS(max_fds) (((max_fds) - 10) / \
-                                      (CLEANUP_NUM_REQS_PER_DAEMON * 5 \
-                                       + 3))
+#define CLEANUP_MAX_DAEMONS(max_fds) ( ((max_fds) < 10) ? 0 : \
+                                         ( (((max_fds) - 10) / \
+                                           (CLEANUP_NUM_REQS_PER_DAEMON * 5 \
+                                            + 3)) ) )
 
 #define EXPECTED_URI_BASE_PATH  "/hello_world"
 #define EXPECTED_URI_QUERY      "a=%26&b=c"
@@ -821,6 +822,8 @@ testExternalGet (void)
   if (! c_no_listen)
     c_d = curlEasyInitForTest ("http://127.0.0.1" EXPECTED_URI_FULL_PATH,
                                d_port, &cbc_d);
+  else
+    c_d = NULL; /* To mute compiler warning only */
 
   c_a = curlEasyInitForTest ("http://127.0.0.1" EXPECTED_URI_FULL_PATH,
                              a_port, &cbc_a);
