@@ -47,7 +47,7 @@
 
 static int oneone;
 
-static int
+static enum MHD_Result
 apc_all (void *cls, const struct sockaddr *addr, socklen_t addrlen)
 {
   (void) cls; (void) addr; (void) addrlen;   /* Unused. Silent compiler warning. */
@@ -70,7 +70,7 @@ copyBuffer (void *ptr, size_t size, size_t nmemb, void *ctx)
 }
 
 
-static int
+static enum MHD_Result
 ahc_echo (void *cls,
           struct MHD_Connection *connection,
           const char *url,
@@ -81,10 +81,20 @@ ahc_echo (void *cls,
 {
   const char *me = cls;
   struct MHD_Response *response;
-  int ret;
+  enum MHD_Result ret;
   (void) version; (void) upload_data;      /* Unused. Silent compiler warning. */
   (void) upload_data_size; (void) unused;  /* Unused. Silent compiler warning. */
 
+  if (NULL == url)
+    fprintf (stderr, "The \"url\" parameter is NULL.\n");
+  if (NULL == method)
+    fprintf (stderr, "The \"method\" parameter is NULL.\n");
+  if (NULL == version)
+    fprintf (stderr, "The \"version\" parameter is NULL.\n");
+  if (NULL == upload_data_size)
+    fprintf (stderr, "The \"upload_data_size\" parameter is NULL.\n");
+  if ((0 != *upload_data_size) && (NULL == upload_data))
+    fprintf (stderr, "Upload data is NULL with non-zero size.\n");
   if (0 != strcmp (me, method))
     return MHD_NO;              /* unexpected method */
   response = MHD_create_response_from_buffer (strlen (url),
@@ -128,6 +138,11 @@ testLongUrlGet ()
 
     c = curl_easy_init ();
     url = malloc (VERY_LONG);
+    if (NULL == url)
+    {
+      zzuf_socat_stop ();
+      return 1;
+    }
     memset (url, 'a', VERY_LONG);
     url[VERY_LONG - 1] = '\0';
     memcpy (url, "http://127.0.0.1:11081/",
@@ -189,6 +204,12 @@ testLongHeaderGet ()
     fprintf (stderr, ".");
     c = curl_easy_init ();
     url = malloc (VERY_LONG);
+    if (NULL == url)
+    {
+      zzuf_socat_stop ();
+      curl_easy_cleanup (c);
+      return 16;
+    }
     memset (url, 'a', VERY_LONG);
     url[VERY_LONG - 1] = '\0';
     url[VERY_LONG / 2] = ':';
@@ -228,8 +249,8 @@ int
 main (int argc, char *const *argv)
 {
   unsigned int errorCount = 0;
-  (void) argc;   /* Unused. Silent compiler warning. */
   const char *sl;
+  (void) argc;   /* Unused. Silent compiler warning. */
 
   sl = strrchr (argv[0], (int) '/');
   oneone = (NULL != sl) ? (NULL != strstr (sl, "11")) : 0;
