@@ -91,6 +91,16 @@ ahc_echo (void *cls,
   int have;
   (void) version; (void) unused;   /* Unused. Silent compiler warning. */
 
+  if (NULL == url)
+    fprintf (stderr, "The \"url\" parameter is NULL.\n");
+  if (NULL == method)
+    fprintf (stderr, "The \"method\" parameter is NULL.\n");
+  if (NULL == version)
+    fprintf (stderr, "The \"version\" parameter is NULL.\n");
+  if (NULL == upload_data_size)
+    fprintf (stderr, "The \"upload_data_size\" parameter is NULL.\n");
+  if ((0 != *upload_data_size) && (NULL == upload_data))
+    fprintf (stderr, "Upload data is NULL with non-zero size.\n");
   if (0 != strcmp ("PUT", method))
     return MHD_NO;              /* unexpected method */
   if ((*done) < 8)
@@ -100,7 +110,11 @@ ahc_echo (void *cls,
     {
       return MHD_NO;
     }
-    if (0 == memcmp (upload_data, &"Hello123"[*done], have))
+    if (0 == have)
+    {
+      (void) 0; /* Do nothing - no data yet */
+    }
+    else if (0 == memcmp (upload_data, &"Hello123"[*done], have))
     {
       *done += have;
       *upload_data_size = 0;
@@ -146,6 +160,7 @@ testInternalPut ()
   for (i = 0; i < LOOP_COUNT; i++)
   {
     fprintf (stderr, ".");
+    done_flag = 0;
     c = curl_easy_init ();
     curl_easy_setopt (c, CURLOPT_URL, "http://127.0.0.1:11080/hello_world");
     curl_easy_setopt (c, CURLOPT_WRITEFUNCTION, &copyBuffer);
@@ -274,6 +289,7 @@ testExternalPut ()
   for (i = 0; i < LOOP_COUNT; i++)
   {
     fprintf (stderr, ".");
+    done_flag = 0;
     c = curl_easy_init ();
     curl_easy_setopt (c, CURLOPT_URL, "http://127.0.0.1:11082/hello_world");
     curl_easy_setopt (c, CURLOPT_WRITEFUNCTION, &copyBuffer);
